Module io

Module io 

Modules

unix
Asynchronous IO structures specific to Unix-like operating systems.

Structs

BufReader
The BufReader struct adds buffering to any reader.
BufStream
Wraps a type that is AsyncWrite and AsyncRead, and buffers its input and output.
BufWriter
Wraps a writer and buffers its output.
DuplexStream
A bidirectional pipe to read and write bytes in memory.
Empty
Empty ignores any data written via AsyncWrite, and will always be empty (returning zero bytes) when read via AsyncRead.
Error
The error type for I/O operations of the Read, Write, Seek, and associated traits.
Interest
Readiness event interest.
Join
Joins two values implementing AsyncRead and AsyncWrite into a single handle.
Lines
Reads lines from an AsyncBufRead.
ReadBuf
A wrapper around a byte buffer that is incrementally filled and initialized.
ReadHalf
The readable half of a value returned from split.
Ready
Describes the readiness state of an I/O resources.
Repeat
An async reader which yields one byte over and over and over and over and over and…
SimplexStream
A unidirectional pipe to read and write bytes in memory.
Sink
An async writer which will move data into the void.
Split
Splitter for the split method.
Take
Stream for the take method.
WriteHalf
The writable half of a value returned from split.

Enums

ErrorKind
A list specifying general categories of I/O error.
SeekFrom
Enumeration of possible methods to seek within an I/O object.

Traits

AsyncBufRead
Reads bytes asynchronously.
AsyncBufReadExt
An extension trait which adds utility methods to AsyncBufRead types.
AsyncRead
Reads bytes from a source.
AsyncReadExt
Reads bytes from a source.
AsyncSeek
Seek bytes asynchronously.
AsyncSeekExt
An extension trait that adds utility methods to AsyncSeek types.
AsyncWrite
Writes bytes asynchronously.
AsyncWriteExt
Writes bytes to a sink.

Functions

copy
Asynchronously copies the entire contents of a reader into a writer.
copy_bidirectional
Copies data in both directions between a and b.
copy_bidirectional_with_sizes
Copies data in both directions between a and b using buffers of the specified size.
copy_buf
Asynchronously copies the entire contents of a reader into a writer.
duplex
Create a new pair of DuplexStreams that act like a pair of connected sockets.
empty
Creates a value that is always at EOF for reads, and ignores all data written.
join
Join two values implementing AsyncRead and AsyncWrite into a single handle.
repeat
Creates an instance of an async reader that infinitely repeats one byte.
simplex
Creates unidirectional buffer that acts like in memory pipe.
sink
Creates an instance of an async writer which will successfully consume all data.
split
Splits a single value implementing AsyncRead + AsyncWrite into separate AsyncRead and AsyncWrite handles.

Type Aliases

Result
A specialized Result type for I/O operations.